# SubscriptionStatus


## Enum

* `DRAFT` (value: `'Draft'`)

* `PENDING_ACTIVATION` (value: `'Pending Activation'`)

* `PENDING_ACCEPTANCE` (value: `'Pending Acceptance'`)

* `ACTIVE` (value: `'Active'`)

* `CANCELLED` (value: `'Cancelled'`)

* `EXPIRED` (value: `'Expired'`)

* `SUSPENDED` (value: `'Suspended'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


